@@ -53,6 +53,7 @@ export class DockLayout extends Layout {
     if (options.spacing !== undefined) {
       this._spacing = Utils.clampDimension(options.spacing);
     }
+    this._document = options.document || document;
     this._hiddenMode =
       options.hiddenMode !== undefined
         ? options.hiddenMode
@@ -342,10 +343,14 @@ export class DockLayout extends Layout {
 
     // Create the root node for the new config.
     if (mainConfig) {
-      this._root = Private.realizeAreaConfig(mainConfig, {
-        createTabBar: () => this._createTabBar(),
-        createHandle: () => this._createHandle()
-      });
+      this._root = Private.realizeAreaConfig(
+        mainConfig,
+        {
+          createTabBar: () => this._createTabBar(),
+          createHandle: () => this._createHandle()
+        },
+        this._document
+      );
     } else {
       this._root = null;
     }
@@ -1094,7 +1099,7 @@ export class DockLayout extends Layout {
    */
   private _createTabBar(): TabBar<Widget> {
     // Create the tab bar using the renderer.
-    let tabBar = this.renderer.createTabBar();
+    let tabBar = this.renderer.createTabBar(this._document);
 
     // Enforce necessary tab bar behavior.
     tabBar.orientation = 'horizontal';
@@ -1140,6 +1145,7 @@ export class DockLayout extends Layout {
   private _dirty = false;
   private _root: Private.LayoutNode | null = null;
   private _box: ElementExt.IBoxSizing | null = null;
+  private _document: Document | ShadowRoot;
   private _hiddenMode: Widget.HiddenMode;
   private _items: Private.ItemMap = new Map<Widget, LayoutItem>();
 }
@@ -1152,6 +1158,13 @@ export namespace DockLayout {
    * An options object for creating a dock layout.
    */
   export interface IOptions {
+    /**
+     * The document to use with the dock panel.
+     *
+     * The default is the global `document` instance.
+     */
+    document?: Document | ShadowRoot;
+
     /**
      * The method for hiding widgets.
      *
@@ -1181,7 +1194,7 @@ export namespace DockLayout {
      *
      * @returns A new tab bar for a dock layout.
      */
-    createTabBar(): TabBar<Widget>;
+    createTabBar(document?: Document | ShadowRoot): TabBar<Widget>;
 
     /**
      * Create a new handle node for use with a dock layout.
@@ -1473,13 +1486,14 @@ namespace Private {
    */
   export function realizeAreaConfig(
     config: DockLayout.AreaConfig,
-    renderer: DockLayout.IRenderer
+    renderer: DockLayout.IRenderer,
+    document: Document | ShadowRoot
   ): LayoutNode {
     let node: LayoutNode;
     if (config.type === 'tab-area') {
-      node = realizeTabAreaConfig(config, renderer);
+      node = realizeTabAreaConfig(config, renderer, document);
     } else {
-      node = realizeSplitAreaConfig(config, renderer);
+      node = realizeSplitAreaConfig(config, renderer, document);
     }
     return node;
   }
@@ -2181,10 +2195,11 @@ namespace Private {
    */
   function realizeTabAreaConfig(
     config: DockLayout.ITabAreaConfig,
-    renderer: DockLayout.IRenderer
+    renderer: DockLayout.IRenderer,
+    document: Document | ShadowRoot
   ): TabLayoutNode {
     // Create the tab bar for the layout node.
-    let tabBar = renderer.createTabBar();
+    let tabBar = renderer.createTabBar(document);
 
     // Hide each widget and add it to the tab bar.
     each(config.widgets, widget => {
@@ -2205,7 +2220,8 @@ namespace Private {
    */
   function realizeSplitAreaConfig(
     config: DockLayout.ISplitAreaConfig,
-    renderer: DockLayout.IRenderer
+    renderer: DockLayout.IRenderer,
+    document: Document | ShadowRoot
   ): SplitLayoutNode {
     // Create the split layout node.
     let node = new SplitLayoutNode(config.orientation);
@@ -2213,7 +2229,7 @@ namespace Private {
     // Add each child to the layout node.
     each(config.children, (child, i) => {
       // Create the child data for the layout node.
-      let childNode = realizeAreaConfig(child, renderer);
+      let childNode = realizeAreaConfig(child, renderer, document);
       let sizer = createSizer(config.sizes[i]);
       let handle = renderer.createHandle();
 
